@@ -23,7 +23,7 @@ module Prawn
 
   FLOAT_PRECISION = 1.0e-9
 
-  # Whe set to true, Prawn will verify hash options to ensure only valid keys
+  # When set to true, Prawn will verify hash options to ensure only valid keys
   # are used.  Off by default.
   #
   # Example:
@@ -76,6 +76,7 @@ require_relative "prawn/images/png"
 require_relative "prawn/stamp"
 require_relative "prawn/soft_mask"
 require_relative "prawn/security"
+require_relative "prawn/transformation_stack"
 require_relative "prawn/document"
 require_relative "prawn/font"
 require_relative "prawn/measurements"
