@@ -6,14 +6,19 @@
 #
 # This is free software. Please see the LICENSE and COPYING files for details.
 
-require_relative '../../prawn/encoding'
+require_relative "../encoding"
 
 module Prawn
   class Font
-
     # @private
 
     class AFM < Font
+      class << self
+        attr_accessor :hide_m17n_warning
+      end
+
+      self.hide_m17n_warning = false
+
       BUILT_INS = %w[ Courier Helvetica Times-Roman Symbol ZapfDingbats
                       Courier-Bold Courier-Oblique Courier-BoldOblique
                       Times-Bold Times-Italic Times-BoldItalic
@@ -31,25 +36,25 @@ module Prawn
             ".", "/usr/lib/afm",
             "/usr/local/lib/afm",
             "/usr/openwin/lib/fonts/afm",
-             Prawn::DATADIR+'/fonts']
+            Prawn::DATADIR + '/fonts'
+          ]
         end
       end
 
       attr_reader :attributes #:nodoc:
 
-      def initialize(document, name, options={}) #:nodoc:
+      def initialize(document, name, options = {}) #:nodoc:
         unless BUILT_INS.include?(name)
-          raise Prawn::Errors::UnknownFont, "#{name} is not a known font."
+          fail Prawn::Errors::UnknownFont, "#{name} is not a known font."
         end
 
         super
 
-        @@winansi   ||= Prawn::Encoding::WinAnsi.new # parse data/encodings/win_ansi.txt once only
         @@font_data ||= SynchronizedCache.new        # parse each ATM font file once only
 
         file_name = @name.dup
         file_name << ".afm" unless file_name =~ /\.afm$/
-        file_name = file_name[0] == ?/ ? file_name : find_font(file_name)
+        file_name = file_name[0] == '/' ? file_name : find_font(file_name)
 
         font_data = @@font_data[file_name] ||= parse_afm(file_name)
         @glyph_widths    = font_data[:glyph_widths]
@@ -71,12 +76,12 @@ module Prawn
       end
 
       # NOTE: String *must* be encoded as WinAnsi
-      def compute_width_of(string, options={}) #:nodoc:
+      def compute_width_of(string, options = {}) #:nodoc:
         scale = (options[:size] || size) / 1000.0
 
         if options[:kerning]
           strings, numbers = kern(string).partition { |e| e.is_a?(String) }
-          total_kerning_offset = numbers.inject(0.0) { |s,r| s + r }
+          total_kerning_offset = numbers.inject(0.0) { |s, r| s + r }
           (unscaled_width_of(strings.join) - total_kerning_offset) * scale
         else
           unscaled_width_of(string) * scale
@@ -94,11 +99,17 @@ module Prawn
       # is replaced with a string in WinAnsi encoding.
       #
       def normalize_encoding(text)
-        enc = @@winansi
-        text.unpack("U*").collect { |i| enc[i] }.pack("C*")
-      rescue ArgumentError
+        text.encode("windows-1252")
+      rescue ::Encoding::InvalidByteSequenceError,
+             ::Encoding::UndefinedConversionError
+
         raise Prawn::Errors::IncompatibleStringEncoding,
-          "Arguments to text methods must be UTF-8 encoded"
+              "Your document includes text that's not compatible with the Windows-1252 character set.\n" \
+              "If you need full UTF-8 support, use TTF fonts instead of PDF's built-in fonts\n."
+      end
+
+      def to_utf8(text)
+        text.encode("UTF-8")
       end
 
       # Returns the number of characters in +str+ (a WinAnsi-encoded string).
@@ -119,24 +130,24 @@ module Prawn
       #
       # The +text+ parameter must be in WinAnsi encoding (cp1252).
       #
-      def encode_text(text, options={})
+      def encode_text(text, options = {})
         [[0, options[:kerning] ? kern(text) : text]]
       end
 
       def glyph_present?(char)
-        if char == "_"
-          true
-        else
-          normalize_encoding(char) != "_"
-        end
+        !!normalize_encoding(char)
+      rescue Prawn::Errors::IncompatibleStringEncoding
+        false
       end
 
       private
 
       def register(subset)
-        font_dict = {:Type     => :Font,
-                     :Subtype  => :Type1,
-                     :BaseFont => name.to_sym}
+        font_dict = {
+          :Type     => :Font,
+          :Subtype  => :Type1,
+          :BaseFont => name.to_sym
+        }
 
         # Symbolic AFM fonts (Symbol, ZapfDingbats) have their own encodings
         font_dict.merge!(:Encoding => :WinAnsiEncoding) unless symbolic?
@@ -152,12 +163,11 @@ module Prawn
         self.class.metrics_path.find { |f| File.exist? "#{f}/#{file}" } + "/#{file}"
       rescue NoMethodError
         raise Prawn::Errors::UnknownFont,
-          "Couldn't find the font: #{file} in any of:\n" +
-           self.class.metrics_path.join("\n")
+              "Couldn't find the font: #{file} in any of:\n" + self.class.metrics_path.join("\n")
       end
 
       def parse_afm(file_name)
-        data    = {:glyph_widths => {}, :bounding_boxes => {}, :kern_pairs => {}, :attributes => {}}         
+        data    = { :glyph_widths => {}, :bounding_boxes => {}, :kern_pairs => {}, :attributes => {} }
         section = []
 
         File.foreach(file_name) do |line|
@@ -187,7 +197,7 @@ module Prawn
             parse_generic_afm_attribute(line, data)
           end
         end
-        
+
         # process data parsed from AFM file to build tables which
         #   will be used when measuring and kerning text
         data[:glyph_table] = (0..255).map do |i|
@@ -195,12 +205,11 @@ module Prawn
         end
 
         character_hash = Hash[Encoding::WinAnsi::CHARACTERS.zip((0..Encoding::WinAnsi::CHARACTERS.size).to_a)]
-        data[:kern_pair_table] = data[:kern_pairs].inject({}) do |h,p|
+        data[:kern_pair_table] = data[:kern_pairs].each_with_object({}) do |p, h|
           h[p[0].map { |n| character_hash[n] }] = p[1]
-          h
         end
 
-        data.each_value { |hash| hash.freeze }
+        data.each_value(&:freeze)
         data.freeze
       end
 
@@ -234,11 +243,11 @@ module Prawn
           e.respond_to?(:force_encoding) ? e.force_encoding(::Encoding::Windows_1252) : e
         }
       end
-      
+
       private
-      
+
       def unscaled_width_of(string)
-        string.bytes.inject(0) do |s,r|
+        string.bytes.inject(0) do |s, r|
           s + @glyph_table[r]
         end
       end
