@@ -16,6 +16,7 @@ module Prawn
         attr_reader :max_line_height
         attr_reader :max_descender
         attr_reader :max_ascender
+        attr_reader :finalized
         attr_accessor :consumed
 
         # The following present only for testing purposes
@@ -31,34 +32,38 @@ module Prawn
         end
 
         def space_count
-          if @unfinalized_line
+          unless finalized
             fail "Lines must be finalized before calling #space_count"
           end
+
           @fragments.inject(0) do |sum, fragment|
             sum + fragment.space_count
           end
         end
 
         def line_width
-          if @unfinalized_line
+          unless finalized
             fail "Lines must be finalized before calling #line_width"
           end
+
           @fragments.inject(0) do |sum, fragment|
             sum + fragment.width
           end
         end
 
         def line
-          if @unfinalized_line
+          unless finalized
             fail "Lines must be finalized before calling #line"
           end
+
           @fragments.collect do |fragment|
             fragment.text.dup.force_encoding(::Encoding::UTF_8)
           end.join
         end
 
         def finalize_line
-          @unfinalized_line = false
+          @finalized = true
+
           omit_trailing_whitespace_from_line_width
           @fragments = []
           @consumed.each do |hash|
@@ -85,7 +90,7 @@ module Prawn
         end
 
         def initialize_line
-          @unfinalized_line = true
+          @finalized = false
           @max_line_height = 0
           @max_descender = 0
           @max_ascender = 0
@@ -99,24 +104,26 @@ module Prawn
         end
 
         def next_string
-          unless @unfinalized_line
+          if finalized
             fail "Lines must not be finalized when calling #next_string"
           end
-          hash = @unconsumed.shift
-          if hash.nil?
-            nil
-          else
-            @consumed << hash.dup
-            @current_format_state = hash.dup
+
+          next_unconsumed_hash = @unconsumed.shift
+
+          if next_unconsumed_hash
+            @consumed << next_unconsumed_hash.dup
+            @current_format_state = next_unconsumed_hash.dup
             @current_format_state.delete(:text)
-            hash[:text]
+
+            next_unconsumed_hash[:text]
           end
         end
 
         def preview_next_string
-          hash = @unconsumed.first
-          if hash.nil? then nil
-          else hash[:text]
+          next_unconsumed_hash = @unconsumed.first
+
+          if next_unconsumed_hash
+            next_unconsumed_hash[:text]
           end
         end
 
@@ -181,9 +188,10 @@ module Prawn
         end
 
         def retrieve_fragment
-          if @unfinalized_line
+          unless finalized
             fail "Lines must be finalized before fragments can be retrieved"
           end
+
           @fragments.shift
         end
 
