@@ -85,10 +85,10 @@ module Prawn
       #
       # Raises "Bad font family" if no font family is defined for the current font
       #
-      # Raises <tt>Prawn::Errrors::CannotFit</tt> if not wide enough to print
+      # Raises <tt>Prawn::Errors::CannotFit</tt> if not wide enough to print
       # any text
       #
-      def formatted_text_box(array, options={})
+      def formatted_text_box(array, options = {})
         Text::Formatted::Box.new(array, options.merge(:document => self)).render
       end
 
@@ -136,7 +136,7 @@ module Prawn
 
         # See Prawn::Text#text_box for valid options
         #
-        def initialize(formatted_text, options={})
+        def initialize(formatted_text, options = {})
           @inked             = false
           Prawn.verify_options(valid_options, options)
           options            = options.dup
@@ -168,7 +168,6 @@ module Prawn
           @rotate            = options[:rotate] || 0
           @rotate_around     = options[:rotate_around] || :upper_left
           @single_line       = options[:single_line]
-          @skip_encoding     = options[:skip_encoding] || @document.skip_encoding
           @draw_text_callback = options[:draw_text_callback]
 
           # if the text rendering mode is :unknown, force it back to :fill
@@ -188,8 +187,8 @@ module Prawn
             options[:kerning] = @document.default_kerning?
           end
           @options = { :kerning => options[:kerning],
-            :size    => options[:size],
-            :style   => options[:style] }
+                       :size    => options[:size],
+                       :style   => options[:style] }
 
           super(formatted_text, options)
         end
@@ -204,7 +203,7 @@ module Prawn
         #
         # Returns any text that did not print under the current settings
         #
-        def render(flags={})
+        def render(flags = {})
           unprinted_text = []
 
           @document.save_font do
@@ -229,7 +228,9 @@ module Prawn
             end
           end
 
-          unprinted_text
+          unprinted_text.map do |e|
+            e.merge(:text => @document.font.to_utf8(e[:text]))
+          end
         end
 
         # The width available at this point in the box
@@ -247,7 +248,7 @@ module Prawn
 
         # <tt>fragment</tt> is a Prawn::Text::Formatted::Fragment object
         #
-        def draw_fragment(fragment, accumulated_width=0, line_width=0, word_spacing=0) #:nodoc:
+        def draw_fragment(fragment, accumulated_width = 0, line_width = 0, word_spacing = 0) #:nodoc:
           case(@align)
           when :left
             x = @at[0]
@@ -278,10 +279,10 @@ module Prawn
             @document.word_spacing(word_spacing) {
               if @draw_text_callback
                 @draw_text_callback.call(fragment.text, :at => [x, y],
-                                         :kerning => @kerning)
+                                                        :kerning => @kerning)
               else
                 @document.draw_text!(fragment.text, :at => [x, y],
-                                     :kerning => @kerning)
+                                                    :kerning => @kerning)
               end
             }
 
@@ -328,28 +329,26 @@ module Prawn
         end
 
         def valid_options
-          PDF::Core::Text::VALID_OPTIONS + [:at, :height, :width,
-                                              :align, :valign,
-                                              :rotate, :rotate_around,
-                                              :overflow, :min_font_size,
-                                              :disable_wrap_by_char,
-                                              :leading, :character_spacing,
-                                              :mode, :single_line,
-                                              :skip_encoding,
-                                              :document,
-                                              :direction,
-                                              :fallback_fonts,
-                                              :draw_text_callback]
+          PDF::Core::Text::VALID_OPTIONS + [
+            :at,
+            :height, :width,
+            :align, :valign,
+            :rotate, :rotate_around,
+            :overflow, :min_font_size,
+            :disable_wrap_by_char,
+            :leading, :character_spacing,
+            :mode, :single_line,
+            :document,
+            :direction,
+            :fallback_fonts,
+            :draw_text_callback
+          ]
         end
 
         private
 
         def normalized_text(flags)
-          if @skip_encoding
-            text = original_text
-          else
-            text = normalize_encoding
-          end
+          text = normalize_encoding
 
           text.each { |t| t.delete(:color) } if flags[:dry_run]
 
@@ -357,7 +356,7 @@ module Prawn
         end
 
         def original_text
-          @original_array.collect { |hash| hash.dup }
+          @original_array.collect(&:dup)
         end
 
         def original_text=(formatted_text)
@@ -484,14 +483,16 @@ module Prawn
           @vertical_alignment_processed = true
 
           return if @vertical_align == :top
+
           wrap(text)
 
           case @vertical_align
           when :center
-            @at[1] = @at[1] - (@height - height) * 0.5
+            @at[1] -= (@height - height + @descender) * 0.5
           when :bottom
-            @at[1] = @at[1] - (@height - height) + @descender
+            @at[1] -= (@height - height)
           end
+
           @height = height
         end
 
@@ -608,9 +609,7 @@ module Prawn
             @document.stroke_line(fragment.strikethrough_points)
           end
         end
-
       end
-
     end
   end
 end
