@@ -13,18 +13,18 @@ require File.expand_path(File.join(File.dirname(__FILE__),
                                    %w[.. example_helper]))
 
 filename = File.basename(__FILE__).gsub('.rb', '.pdf')
-Prawn::Example.generate(filename) do
+Prawn::ManualBuilder::Example.generate(filename) do
   stroke_axis
 
   stroke_color "ff0000"
-  
+
   stroke do
     # just lower the current y position
-    move_down 50  
+    move_down 50
     horizontal_rule
-    
+
     vertical_line   100, 300, :at => 50
-  
+
     horizontal_line 200, 500, :at => 150
   end
 end
