@@ -16,7 +16,7 @@ Prawn::ManualBuilder::Example.generate(filename) do
 
   file = "#{Prawn::DATADIR}/fonts/Panic+Sans.dfont"
   font_families["Panic Sans"] = {
-    :normal => { :file => file, :font => "PanicSans" },
+    :normal => { :file => file, :font => "PanicSans" }
   }
 
   font("Panic Sans") do
@@ -31,7 +31,7 @@ Prawn::ManualBuilder::Example.generate(filename) do
   move_down 20
 
   formatted_text([ { :text => "Fallback fonts can even override" },
-                   { :text => "fragment fonts (你好)", :font => "Times-Roman" },
+                   { :text => "fragment fonts (你好)", :font => "Times-Roman" }
                  ],
                  :fallback_fonts => ["Times-Roman", "Kai"])
 end
