@@ -23,4 +23,11 @@ Prawn::ManualBuilder::Example.generate(filename) do
   text "This paragraph will be indented. " * 10 +
        "\n" + "This one will too. " * 10,
        :indent_paragraphs => 60
+
+  move_down 20
+
+  text "FROM RIGHT TO LEFT:"
+  text "This paragraph will be indented. " * 10 +
+       "\n" + "This one will too. " * 10,
+       :indent_paragraphs => 60, :direction => :rtl
 end
