@@ -63,7 +63,7 @@ describe "#text" do
   end
 
   it "should ignore call when string is nil" do
-    expect(@pdf.text(nil)).to be_false
+    expect(@pdf.text(nil)).to eq false
   end
 
   it "should correctly render empty paragraphs" do
@@ -91,13 +91,13 @@ describe "#text" do
   it "should default to use kerning information" do
     @pdf.text "hello world"
     text = PDF::Inspector::Text.analyze(@pdf.render)
-    expect(text.kerned[0]).to be_true
+    expect(text.kerned[0]).to eq true
   end
 
   it "should be able to disable kerning with an option" do
     @pdf.text "hello world", :kerning => false
     text = PDF::Inspector::Text.analyze(@pdf.render)
-    expect(text.kerned[0]).to be_false
+    expect(text.kerned[0]).to eq false
   end
 
   it "should be able to disable kerning document-wide" do
@@ -105,14 +105,14 @@ describe "#text" do
     @pdf.default_kerning = false
     @pdf.text "hello world"
     text = PDF::Inspector::Text.analyze(@pdf.render)
-    expect(text.kerned[0]).to be_false
+    expect(text.kerned[0]).to eq false
   end
 
   it "option should be able to override document-wide kerning disabling" do
     @pdf.default_kerning = false
     @pdf.text "hello world", :kerning => true
     text = PDF::Inspector::Text.analyze(@pdf.render)
-    expect(text.kerned[0]).to be_true
+    expect(text.kerned[0]).to eq true
   end
 
   it "should raise_error ArgumentError if :at option included" do
@@ -480,25 +480,19 @@ describe "#text" do
   describe "kerning" do
     it "should respect text kerning setting (document default)" do
       create_pdf
-      @pdf.font.expects(:compute_width_of).with do |str, options|
-        str == "VAT" && options[:kerning] == true
-      end.at_least_once.returns(10)
+      expect(@pdf.font).to receive(:compute_width_of).with("VAT", hash_including(kerning: true)).and_return(10)
       @pdf.text "VAT"
     end
 
     it "should respect text kerning setting (kerning=true)" do
       create_pdf
-      @pdf.font.expects(:compute_width_of).with do |str, options|
-        str == "VAT" && options[:kerning] == true
-      end.at_least_once.returns(10)
+      expect(@pdf.font).to receive(:compute_width_of).with("VAT", hash_including(kerning: true)).at_least(:once).and_return(10)
       @pdf.text "VAT", :kerning => true
     end
 
     it "should respect text kerning setting (kerning=false)" do
       create_pdf
-      @pdf.font.expects(:compute_width_of).with do |str, options|
-        str == "VAT" && options[:kerning] == false
-      end.at_least_once.returns(10)
+      expect(@pdf.font).to receive(:compute_width_of).with("VAT", hash_including(kerning: false)).at_least(:once).and_return(10)
       @pdf.text "VAT", :kerning => false
     end
   end
